This directory is used for testing MyPy type-checking against stub files
generated by bravado-types.

Each subdirectory should contain one or more schema files with extension .json, .yml, or .yaml, as well as one or more .py modules. Modules are annotated with comments indicating the expected MyPy output for each line. The test code will perform code generation on the schemas, then invoke MyPy for each .py file and check the output against the comments.

To customize code generation for a test case, add a *test.cfg* file with a
section for each schema file. Sections support the following properties:

* `schema_file`: Schema filename
* `py_file`: (Optional) Generated module filename
* `name`: (Optional) Schema name
* `args`: (Optional) Extra CLI args. If specified, the test harness will use
  the CLI for code generation.

See [*tests/test_mypy.py*](../test_mypy.py) for details.
